class HD返回值:
    RET_检查PID存在 = 8
    RET_环境已卸载 = 7
    RET_重连窗口序号不一致 = 6
    RET_重连窗口 = 5
    RET_状态变动 = 4
    RET_暂停过 = 3
    RET_结束 = 2
    RET_成功 = 1
    RET_失败 = 0
    RET_真 = 1
    RET_非 = 0
    ERROR_未初始化全局环境 = -1000
    ERROR_未找到进程环境 = -1001
    ERROR_进程环境内存为NULL = -1002
    ERROR_获取CALL环境失败 = -1003
    ERROR_超时返回 = -1004
    ERROR_主线程调用超时返回 = -1005
    ERROR_数据异常 = -1006
    ERROR_参数错误 = -1007
    ERROR_未挂接主线程 = -1008
    ERROR_后台绑定句柄无效 = -1009
    ERROR_未绑定后台 = -1010
    ERROR_多开超出限制 = -1011
    ERROR_字符串为空 = -1012
    ERROR_地址为空 = -1013
    ERROR_未知错误 = -1014
    ERROR_远进程申请内存失败 = -1015
    ERROR_文件夹创建失败 = -1016
    ERROR_异步无法获取返回值 = -1017
    ERROR_语法错误 = -1018
    ERROR_申请内存失败 = -1019
    ERROR_创建线程失败 = -1020
    ERROR_缓冲区大小不足 = -1021
    ERROR_未初始化LUA = -1022
    ERROR_LUA状态机为NULL = -1023
    ERROR_未找到LUA函数 = -1024
    ERROR_返回值未知类型 = -1025
    ERROR_LUA线程标识符不符合 = -1026
    ERROR_模块获取失败 = -1027
    ERROR_地址不可读 = -1028
    ERROR_返回值为JSON = -1029
    ERROR_获取数据失败 = -1030
    ERROR_未初始化 = -1031
    ERROR_已经开启 = -1032
    ERROR_已经结束 = -1033
    ERROR_未开启 = -1034
    ERROR_未结束 = -1035
    ERROR_高宽为0 = -1036
    ERROR_数据为NULL = -1037
    ERROR_数据不符合要求 = -1038
    ERROR_文件打开失败 = -1039
    ERROR_打开失败 = -1040
    ERROR_解析失败 = -1041
    ERROR_无游戏类型 = -1042
    ERROR_HOOK失败 = -1043
    ERROR_UNHOOK失败 = -1044
    ERROR_功能失效 = -1045
    ERROR_无效PE文件格式 = -1046
    ERROR_未找到PE头 = -1047
    ERROR_重定位表失败 = -1048
    ERROR_未找到函数入口 = -1049
    ERROR_无法附加DLL = -1050
    ERROR_接口数量上限 = -1051
    ERROR_已经存在 = -1052
    ERROR_打开句柄失败 = -1053
    ERROR_未找到全局环境 = -1054
    ERROR_组件数量上限 = -1055
    ERROR_未找到组件接口 = -1056
    ERROR_接口类型不匹配 = -1057
    ERROR_组件无效 = -1058
    ERROR_接口地址无效 = -1059
    ERROR_生成密钥失败 = -1060
    ERROR_加密失败 = -1061
    ERROR_解密失败 = -1062
    ERROR_DLL中无此接口 = -1063
    ERROR_下载失败 = -1064
    ERROR_注册表操作失败 = -1065
    ERROR_路径获取失败 = -1066
    ERROR_提权失败 = -1067
    ERROR_驱动已安装 = -1068
    ERROR_HD驱动已安装无法安装HN驱动 = -1069
    ERROR_资源未找到 = -1070
    ERROR_资源加载失败 = -1071
    ERROR_提取资源失败 = -1072
    ERROR_未加载插件 = -1073
    ERROR_文件无法保存 = -1074
    ERROR_打开目录失败 = -1075
    ERROR_写入文件的字节大小不符合要求 = -1076
    ERROR_删除文件失败 = -1077
    ERROR_获取字符串失败 = -1078
    ERROR_获取注册表值失败 = -1079
    ERROR_类型错误 = -1080
    ERROR_参数不符合要求 = -1081
    ERROR_区域超出 = -1082
    ERROR_文件不存在 = -1083
    ERROR_创建文件失败 = -1084
    ERROR_文件读取失败 = -1085
    ERROR_与系统驱动通讯失败 = -1086
    ERROR_创建管道失败 = -1087
    ERROR_创建进程失败 = -1088
    ERROR_未找到相关字符串信息 = -1089
    ERROR_缓冲区大小不充足 = -1090
    ERROR_数据类型转换失败 = -1091
    ERROR_格式化字符串失败 = -1092
    ERROR_网络超时 = -1093
    ERROR_网络连接失败 = -1094
    ERROR_加载指定DLL失败 = -1095
    ERROR_解析字符串失败 = -1096
    ERROR_窗口大小变动导致数据不一致 = -1097
    ERROR_打开剪切板失败 = -1098
    ERROR_加锁失败 = -1099
    ERROR_获取剪切板数据失败 = -1100
    ERROR_版本号获取失败 = -1101
    ERROR_已经绑定其他设备 = -1102
    ERROR_已经达到最大在线数 = -1103
    ERROR_账号或密码为空 = -1104
    ERROR_验证失败 = -1105
    ERROR_打开进程失败 = -1106
    ERROR_进程位数不匹配 = -1107
    ERROR_添加进程环境失败 = -1108
    ERROR_定位特征地址失败 = -1109
    ERROR_寻找空白地址失败 = -1110
    ERROR_无操作类型 = -1111
    ERROR_无相关句柄 = -1112
    ERROR_无HDC句柄 = -1113
    ERROR_获取矩形大小失败 = -1114
    ERROR_拷贝数据失败 = -1115
    ERROR_无效句柄 = -1116
    ERROR_创建对象失败 = -1117
    ERROR_截图方式需要重开才能切换 = -1118
    ERROR_格式有误 = -1119
    ERROR_字库数据为空 = -1120
    ERROR_字库中未找到相应字 = -1121
    ERROR_大小计算为0 = -1122
    ERROR_容器大小不一致 = -1123
    ERROR_句柄无效 = -1124
    ERROR_获取PID无效 = -1125
    ERROR_获取大小失败 = -1126
    ERROR_获取失败 = -1127
    ERROR_未找到 = -1128
    ERROR_立即返回无效值 = -1129
    ERROR_未设置路径 = -1130
    ERROR_文件操作失败 = -1131
    ERROR_写入内存失败 = -1132
    ERROR_模块查找失败 = -1133
    ERROR_接口查找失败 = -1134
    ERROR_组件信息保存失败 = -1135
    ERROR_组件加载失败 = -1136
    ERROR_组件卸载失败 = -1137
    ERROR_组件不符合卸载要求 = -1138
    ERROR_进程环境句柄为NULL = -1139
    ERROR_未绑定PID = -1140
    ERROR_读取图片失败 = -1141
    ERROR_打开注册表失败 = -1142
    ERROR_获取注册表失败 = -1143
    ERROR_写内存失败 = -1144
    ERROR_清除缓存失败 = -1145
    ERROR_字体无宽度 = -1146
    ERROR_裁剪矩形数据失败 = -1147
    ERROR_图片无宽或高 = -1148
    ERROR_功能未开放 = -1149
    ERROR_模块信息获取失败 = -1150
    ERROR_未找到合适的JMP地址 = -1151
    ERROR_HOOK初始化失败 = -1152
    ERROR_无HOOK接口类型 = -1153
    ERROR_CALL类型不匹配 = -1154
    ERROR_创建通讯失败 = -1155
    ERROR_加载通讯失败 = -1156
    ERROR_数据格式错误 = -1157
    ERROR_地址失效 = -1158
    ERROR_坐标转换失败 = -1159
    ERROR_容器为空 = -1160
    ERROR_数据为空 = -1161
    ERROR_特征不符合 = -1162
    ERROR_范围未确定 = -1163
    ERROR_缓冲区不足 = -1164
    ERROR_此接口调试版本无效 = -1165
    ERROR_子图不在范围内 = -1166
    ERROR_插件数量上限 = -1167
    ERROR_API枚举失败 = -1168
    ERROR_无法定位模块 = -1169
    ERROR_无效HOOK地址 = -1170
    ERROR_无对应的HOOK函数 = -1171
    ERROR_破坏字节超过容量 = -1172
    ERROR_指定地址不适合HOOK = -1173
    ERROR_没有充足的HOOK大小 = -1174
    ERROR_设置回调地址失败 = -1175
    ERROR_API获取时间失败 = -1176
    ERROR_无效插件序号 = -1177
    ERROR_进程不存在 = -1178
    ERROR_未安装插件 = -1179
    ERROR_初始化通讯失败 = -1180
    ERROR_未初始化通讯序号 = -1181
    ERROR_当前线程字库为空 = -1182
    ERROR_线程数量超出限制 = -1183
    ERROR_字库序号不存在 = -1184
    ERROR_释放资源失败 = -1185
    ERROR_超出容量 = -1186
    ERROR_空模型 = -1187
    ERROR_环境序号不存在 = -1188
    ERROR_回调处理中 = -1189
    ERROR_无法操作绑定窗口 = -1190
    ERROR_接口已被移除 = -1191
    ERROR_不支持类型 = -1192
    ERROR_初始化失败 = -1193
    ERROR_环境被卸载 = -1194
    ERROR_进程已经关闭 = -1195
    ERROR_中控环境未初始化 = -1196
    ERROR_未加载HD驱动 = -1197
    ERROR_未绑定设备 = -1198
    ERROR_未找到进程 = -1199
    ERROR_进程PID不匹配 = -1200
    ERROR_前台模式无法后台 = -1201
    ERROR_JMP地址无效 = -1202
    ERROR_HOOK地址无效 = -1203
    ERROR_类型和HOOK地址不匹配 = -1204
    ERROR_不在HD多线程环境下 = -1205
    ERROR_未连接 = -1206
    ERROR_进程环境已被卸载 = -1207
    ERROR_安装插件失败 = -1208 #检查是否安装了驱动
    ERROR_安装驱动失败 = -1209 #检查是否管理员或者杀毒或者关闭内核隔离
    ERROR_加载环境失败 = -1210 #检查账号是否欠费或者网络问题或者参数不符合要求
    ERROR_初始化序号失败 = -1211 #一般不会失败
    ERROR_获取PID超时返回 = -1212 #确定是否打开进程成功或者增大等待时间
    ERROR_获取状态值20超时返回 = -1213 #未安装插件或被拦截或增大等待时间
    ERROR_获取状态值120超时返回 = -1214 #未安装插件或被拦截或增大等待时间
    ERROR_继续失败 = -1215 #可能未初始化相关环境 一般不会失败
    ERROR_当前进程插件序号不一致 = -1216 #说明指定的PID进程绑定的窗口序号已经存在  与指定的序号不一致  调用HCInject_GetPreWinIndex  获取指定PID的绑定的窗口序号
    ERROR_PID无效 = -1217
    ERROR_扩展序号不能用 = -1218#扩展序号不能自己指定
    ERROR_接口丢弃 = -1219 #老版本的接口丢弃
    ERROR_序号超出限制 = -1220
    ERROR_已经重启 = -1221
    ERROR_登录中无法重启 = -1222
    ERROR_暂停中无法重启 = -1223
    ERROR_操作中无法重启 = -1224
    ERROR_强制关闭线程中无法发送 = -1225
    ERROR_卸载失败 = -1226
    ERROR_未完全开启 = -1227
    ERROR_逻辑异常 = -1228
    ERROR_无法连接VNC = -1229
    ERROR_未连接过VNC = -1230
    ERROR_未关联过VM = -1231
    ERROR_未获取截图环境 = -1232
    ERROR_环境为NULL = -1233
    ERROR_区域无效 = -1234
    ERROR_继续当前操作 = -1235
    ERROR_加解密失败 = -1236
    ERROR_未安装驱动 = -1237
    ERROR_调试版本无法加解密 = -1238
    ERROR_截图缓存不存在 = -1239
    #=============================================
    LOGINERROR_错误 =  -2000 #如果大于这个值也表示成功 = 可能返回的是点数不足 = 小于这个值表示错误
    LOGINERROR_客户端数据为空 = -2001
    LOGINERROR_账号卡密不匹配 = -2002
    LOGINERROR_登记登录数据失败 = -2003
    LOGINERROR_客户端数据太多 = -2004
    LOGINERROR_未找到客户端数据 = -2005
    LOGINERROR_账号类型为空 = -2006
    LOGINERROR_账号扣点失败 = -2007
    LOGINERROR_更新客户端加载信息失败 = -2008
    LOGINERROR_账号点数不足 = -2009
    LOGINERROR_查询客户端加载信息失败 = -2010
    LOGINERROR_试用卡 = -2011
    LOGINERROR_发布版本无法使用测试账号 = -2012
    LOGINERROR_老版本丢弃 = -2013
    LOGINERROR_数据错误 = -2014
    #=============================================
    #驱动接口返回值： = 大于等于0 = 为成功 =  =  = 特殊:-1068为驱动已经安装 = 可以忽视！
    #驱动宏返回值
    #宏返回值
    #这个值必须大于0 = 用在最开始加载驱动的返回 = 小于0会蓝屏！！
    LOAD_SUCCESS = 0x00000001
    #下面的值是其他接口自定义返回值 = 必须小于0 = 大于0统一返回的都是0！！
    DRERROR_SUCCESS = 0x00000002
    DRERROR_SUCCESSEX = 0xE0000000
    DRERROR_SUCCESSTEST = 0xE0000001
    DRERROR_EXIST = 0xE0000002
    DRERROR_FAID = 0xE0000003
    DRERROR_无法打开进程 = 0xE0000004
    DRERROR_无效的句柄表 = 0xE0000005
    DRERROR_用户验证失败 = 0xE0000006
    DRERROR_内存类型不符 = 0xE0000007
    DRERROR_超出内存范围 = 0xE0000008
    DRERROR_隐藏内存失败 = 0xE0000009
    DRERROR_查询内存失败 = 0xE000000A
    DRERROR_申请内存失败 = 0xE000000B
    DRERROR_超出读写字节 = 0xE000000C
    DRERROR_分配内存失败 = 0xE000000D
    DRERROR_无效的缓冲区 = 0xE000000E
    DRERROR_无法结束自身 = 0xE000000F
    DRERROR_无法识别数据 = 0xE0000010
    DRERROR_进程位数错误 = 0xE0000011
    DRERROR_读写地址错误 = 0xE0000012
    DRERROR_劫持线程失败 = 0xE0000013
    DRERROR_X86DLL格式有误 = 0xE0000014
    DRERROR_X64DLL格式有误 = 0xE0000015
    DRERROR_无合适处理器 = 0xE0000016
    DRERROR_未找到鼠标 = 0xE0000017
    DRERROR_未找到键盘 = 0xE0000018
    DRERROR_未找到入口参数 = 0xE0000019#没有找到入口参数
    DRERROR_输入缓冲区为空 = 0xE0000020#输入缓冲区为空
    DRERROR_未找到模块基址 = 0xE0000021
    DRERROR_未找到函数地址 = 0xE0000022
    ERROR_参数有误 = 0xE0000023#参数有误
